@@ -21,6 +21,16 @@ pairsDAFS = function(x,...){
         rect(breaks[-nB], 0, breaks[-1], y, col = "gray80", ...)
     }
 
+    panel.cor = function(x, y, digits=2, prefix="", cex.cor){
+         usr <- par("usr"); on.exit(par(usr))
+         par(usr = c(0, 1, 0, 1))
+         r <- abs(cor(x, y))
+         txt <- format(c(r, 0.123456789), digits=digits)[1]
+         txt <- paste(prefix, txt, sep="")
+         if(missing(cex.cor)) cex <- 0.8/strwidth(txt)
+         text(0.5, 0.5, txt, cex = cex * r)
+     }
+
     pairs(x, upper.panel = panel.smooth.mod, lower.panel = panel.cor,
         diag.panel = panel.hist.mod, ...)
 }
